{% load i18n static %}<!DOCTYPE html>
{% get_current_language as LANGUAGE_CODE %}
<html lang="{{ LANGUAGE_CODE|default:"en-us" }}">
<head>
<title>{% block title %}{{ page_title }} | {{ site_title|default:_('Djaken') }}{% endblock %}</title>
<link rel="stylesheet" type="text/css" href="{% block stylesheet %}{% static "djaken/css/base.css" %}{% endblock %}" />
{% block extrastyle %}{% endblock %}
{% block blockbots %}<meta name="robots" content="NONE,NOARCHIVE" />{% endblock %}
</head>

{% load i18n %}

<body class="{% if is_popup %}popup {% endif %}{% block bodyclass %}{% endblock %}"
  data-admin-utc-offset="{% now "Z" %}">

<!-- Container -->
<div id="container">

    {% if not is_popup %}

    <!-- Header -->
    <div id="header">
        <div id="branding">
        {% block branding %}<h1 id="site-header"><a href="{% url 'djaken:all_notes' %}">{{ site_header|default:_('Djaken Notes') }}</a></h1>{% endblock %}
        </div>
        {% block usertools %}
        {% if user_is_logged_in %}
        <div id="user-tools">
            {% block welcome-msg %}
                {% trans 'Welcome,' %}
                <strong>{% firstof user.get_short_name user.get_username %}</strong>.
            {% endblock %}
            {% block userlinks %}
                <a href="{% url 'djaken:logout' %}">{% trans 'Log out' %}</a>
            {% endblock %}
        </div>
        {% endif %}
        {% endblock %}
    </div>
    <!-- END Header -->

    {% block breadcrumbs %}
    <div class="breadcrumbs">
    <a href="{% url 'djaken:all_notes' %}">{{ site_title|default:_('Djaken') }}</a>
    {% if page_title %} &rsaquo; {{ page_title }}{% endif %}
    </div>
    {% endblock %}
    {% endif %}

    {% block messages %}
        {% if messages %}
        <ul class="messagelist">{% for message in messages %}
          <li{% if message.tags %} class="{{ message.tags }}"{% endif %}>{{ message|capfirst }}</li>
        {% endfor %}</ul>
        {% endif %}
    {% endblock messages %}

    <!-- Content -->
    <div class="content_title">
        {% block content_title %}{% if content_title %}<h1>{{ content_title }}</h1>{% endif %}{% endblock %}
    </div>
    <div id="content">
        {% block content %}
        {{ content }}
        {% endblock %}
        {% block sidebar %}{% endblock %}
        <br class="clear" />
    </div>
    <!-- END Content -->

    {% block footer %}<div id="footer"></div>{% endblock %}
</div>
<!-- END Container -->

</body>
</html>
