# -*- coding: utf-8 -*-
# Generated by Django 1.11.11 on 2018-04-10 19:52
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djaken', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Image',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('image_data', models.TextField(blank=True, editable=False)),
                ('encrypted_image_data', models.TextField(blank=True, editable=False)),
                ('encryption_iv', models.CharField(blank=True, editable=False, max_length=64)),
            ],
        ),
        migrations.AlterField(
            model_name='note',
            name='content',
            field=models.TextField(blank=True),
        ),
        migrations.AlterField(
            model_name='note',
            name='content_encrypted',
            field=models.TextField(blank=True, editable=False),
        ),
        migrations.AlterField(
            model_name='note',
            name='content_html',
            field=models.TextField(blank=True, editable=False),
        ),
        migrations.AlterField(
            model_name='note',
            name='encryption_iv',
            field=models.CharField(blank=True, editable=False, max_length=64),
        ),
        migrations.AddField(
            model_name='image',
            name='note',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='djaken.Note'),
        ),
    ]
