# -*- coding: utf-8 -*-
# Generated by Django 1.11.11 on 2018-04-03 22:35
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Note',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=255)),
                ('content', models.TextField()),
                ('content_html', models.TextField(editable=False)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('modified', models.DateTimeField(auto_now=True)),
                ('relevant', models.BooleanField(default=True)),
                ('is_encrypted', models.BooleanField(default=False, editable=False)),
                ('content_encrypted', models.TextField(editable=False)),
                ('encryption_iv', models.CharField(editable=False, max_length=64)),
                ('author', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['-relevant', '-modified'],
            },
        ),
    ]
