h1.title {
    font-size: 20px;
    font-weight: 900;
    color: #417690;
}

h2.subtitle {
    font-size: 18px;
    font-weight: 900;
    color: #5D92AC;
}

table, tr, td {
    margin: 0;
    border: 0;
    padding: 0;
    vertical-align: middle;
}

table.outer {
    width: 100%;
}

table.inner {
    display: inline-table;
}

div.controls table.outer {
    text-align: right;
}

div.controls table.outer td.control_button {
    text-align: right;
}

div.note_content table {
    border-collapse: collapse;
    width: 100%;
}

div.note_content td, div.note_content th {
    border: 1px solid #ddd;
    padding: 8px;
    font-size: inherit;
}

div.note_content tr:nth-child(even) {
    background-color: #F2F2F2;
}

div.note_content tr:hover {
    background-color: #DDD;
}

div.note_content th {
    padding-top: 12px;
    padding-bottom: 12px;
    text-align: left;
    background-color: #BED5E0;
}

div.note_content thead th {
    text-transform: none;
    color: #333;
    font-weight: 700;
    font-size: inherit;
}

a.edit_button {
    background: url(../img/icon-edit-note.png) no-repeat center;
    background-size: cover;
    width: 24px;
    height: 24px;
    display: inline-block;
    margin: 0 5px;
}

div.note_content {
    font-size: 12px;
    padding: 0 10px 40px 10px;
}

div.footer {
    position: relative;
    width: 100%;
}

div.footer p {
    font-size: 11px;
    margin: 0.2em 0.2em 0.2em 0.2em;
    color: #666;
    text-align: right;
    clear: both;
}

div.footer p.encryption_icon {
    background: url(../img/icon-lock.png) no-repeat center;
    background-size: cover;
    width: 16px;
    height: 16px;
    float: right;
    display: inline-block;
    margin: 0 5px;
}

div.footer p.note_relevant {
    color: #3a3;
}

div.footer p.note_not_relevant {
    color: #f66;
}

div.footer p time {
    color: #333;
}

/* TOGGLE  BUTTON CLASSES */
.toggle-control {
    transition: 0.3s cubic-bezier(0.95, 0.05, 0.795, 0.035);
    margin: 0px 5px;
    width: 2em;
    height: 1em;
    display: block;
    border: 1px solid #999;
    border-radius: 1em;
    background-color: #f66;
    position: relative;
}
    
.toggle-control:after {
    transition: 0.3s cubic-bezier(0.95, 0.05, 0.795, 0.035);
    content: "";
    width: 1em;
    height: 1em;
    display: block;
    background-color: #fff;
    border-radius: 50%;
    box-shadow: 0 1px 2px rgba(0, 0, 0, 0.4), 0 3px 2px rgba(0, 0, 0, 0.4);
    position: absolute;
    top: 0;
    left: 0;
}
    
.toggle-control:active {
    background-color: #3c5;
}
    
.toggle-control:active:after {
    left: 1em;
}

.toggle-on.toggle-control {
    background-color: #3c5;
}
 
.toggle-on.toggle-control:after {
    left: 1em;
}
 

.toggle-on.toggle-control:active {
    background-color: #f66;
}

.toggle-on.toggle-control:active:after {
    left: 0;
}
/* END: TOGGLE  BUTTON CLASSES */
