table, tr, td {
    margin: 0;
    border: 0;
    padding: 0;
    vertical-align: middle;
}

table.outer {
    width: 100%;
}

table.inner {
    display: inline-table;
}

div.search_and_new {
    margin: 0 0 10px 0;
}

div.search_and_new table.outer {
    text-align: left;
}

div.search_and_new table.outer td.new_note_button {
    text-align: right;
}

div.search_and_new input[type=text] {
    width: 400px;
}

a.search_button {
    background: url(../img/icon-search.png) no-repeat center;
    background-size: cover;
    width: 24px;
    height: 24px;
    display: inline-block;
    margin: 0 5px;
}

a.erase_button {
    background: url(../img/icon-erase.png) no-repeat center;
    background-size: cover;
    width: 24px;
    height: 24px;
    display: inline-block;
    margin: 0 5px;
}

a.new_note_button {
    background: url(../img/icon-new-note.png) no-repeat center;
    background-size: cover;
    width: 24px;
    height: 24px;
    display: inline-block;
    margin: 0 5px;
}

p.encryption_icon {
    background: url(../img/icon-lock.png) no-repeat center;
    background-size: cover;
    width: 16px;
    height: 16px;
    display: inline-block;
    margin: 0 5px;
}

div.filters {
    margin: 0 0 5px 0;
}

div.filters table.outer {
    text-align: right;
}

div.filters table.inner td {
    padding: 0 0 0 16px;
}

div.filters table.inner td.filter_buttons {
    padding: 0;
}

div.filters p {
    font-size: 11px;
    color: #666;
    margin: 0;
}

div.filters td.filter_label p {
    font-weight: 700;
    color: #333;
}

div.arrow_up {
    width: 0;
    height: 0;
    margin: 5px;
    padding: 0;
    background: transparent;
    border-radius: 0;
    border-left: 8px solid transparent;
    border-right: 8px solid transparent;
    border-bottom: 8px solid #447e9b;
}

div.arrow_down {
    width: 0;
    height: 0;
    margin: 5px;
    padding: 0;
    background: transparent;
    border-radius: 0;
    border-left: 8px solid transparent;
    border-right: 8px solid transparent;
    border-top: 8px solid #447e9b;
}



div.each_note {
    border-radius: 0.25em;
    border-style: solid;
    border-width: 1px;
    border-color: #ccc;
    background: #ced5e7;
    padding: 2px 10px;
    margin: 5px 0px;
}

div.each_note table.outer {
    text-align: right;
}

div.each_note table.inner td {
    padding: 0 0 0 8px;
}

div.each_note p {
    font-size: 11px;
    margin: 0.2em 0.2em 0.2em 0.2em; 
    color: #666;
}

div.each_note h2 {
    font-size: 14px;
    margin: 0.2em 0.2em 0.2em 0.2em; 
}

#content p time {
    color: #333;
}

#content p.note_relevant {
    color: #3a3;
}

#content p.note_not_relevant {
    color: #f66;
}



/* TOGGLE  BUTTON CLASSES */
.toggle-control {
    transition: 0.3s cubic-bezier(0.95, 0.05, 0.795, 0.035);
    margin: 0px 5px;
    width: 2em;
    height: 1em;
    display: block;
    border: 1px solid #999;
    border-radius: 1em;
    background-color: #ccc;
    position: relative;
}

.toggle-control:after {
    transition: 0.3s cubic-bezier(0.95, 0.05, 0.795, 0.035);
    content: "";
    width: 1em;
    height: 1em;
    display: block;
    background-color: #fff;
    border-radius: 50%;
    box-shadow: 0 1px 2px rgba(0, 0, 0, 0.4), 0 3px 2px rgba(0, 0, 0, 0.4);
    position: absolute;
    top: 0;
    left: 0;
}

.toggle-control:active {
    background-color: #3c5;
}

.toggle-control:active:after {
    left: 1em;
}

.toggle-on.toggle-control {
    background-color: #3c5;
}

.toggle-on.toggle-control:after {
    left: 1em;
}


.toggle-on.toggle-control:active {
    background-color: #ccc;
}

.toggle-on.toggle-control:active:after {
    left: 0;
}
/* END: TOGGLE  BUTTON CLASSES */
