table, tr, td {
    margin: 0;
    border: 0;
    padding: 0;
    vertical-align: middle;
}

table.outer {
    width: 100%;
}

table.inner {
    display: inline-table;
}

div.controls table.outer {
    text-align: right;
}

div.controls table.outer td.control_button {
    text-align: right;
}


div.note_content {
    padding: 0 10px 0 10px;
}

p.view_note {
    padding: 0 0 5px 0;
    text-align: right;
}

a:hover {
    cursor: pointer;
}

a.erase_button {
    background: url(../img/icon-erase.png) no-repeat center;
    background-size: cover;
    width: 24px;
    height: 24px;
    display: inline-block;
    margin: 0 5px;
}

a.save_button {
    background: url(../img/icon-save.png) no-repeat center;
    background-size: cover;
    width: 24px;
    height: 24px;
    display: inline-block;
    margin: 0 10px;
}

a.save_and_view_button {
    background: url(../img/icon-save-and-view.png) no-repeat center;
    background-size: cover;
    width: 48px;
    height: 24px;
    display: inline-block;
    margin: 0 10px;
}

a.view_button {
    background: url(../img/icon-view.png) no-repeat center;
    background-size: cover;
    width: 24px;
    height: 24px;
    display: inline-block;
    margin: 0 10px;
}

input[type=submit]#save_form {
    display: none;
    width: 0;
    height: 0;
    margin: 0 0;
}

div.note_content input[type=text], div.note_content textarea {
    font-family: 'Roboto Mono';
    font-style: normal;
    font-weight: 400;
    margin: 5px 0;
    width: 98%;
}

div.note_content textarea {
    height: 400px;
}

img#image_preview {
    margin: 10px 5px;
}

div.image_attach_selector {
    margin: 10px 5px;
    width: 48px;
    height: 48px;
    background: url('../img/icon-image-attach.png');
    overflow: hidden;
}

div.image_attach_selector input {
    width: 64px !important;
    height: 48px !important;
    display: block !important;
    opacity: 0 !important;
    overflow: hidden !important;
}

table.image_attach, table.image_attach tr, table.image_attach td {
    border: 0;
    margin: 0;
    paddding: 0;
}

div.footer p {
    font-size: 11px;
    margin: 0.2em 0.2em 0.2em 0.2em;
    color: #666;
    text-align: right;
    clear: both;
}

div.footer p.encryption_icon {
    background: url(../img/icon-lock.png) no-repeat center;
    background-size: cover;
    width: 16px;
    height: 16px;
    float: right;
    display: inline-block;
    margin: 0 5px;
}

div.footer p.note_relevant {
    color: #3a3;
}

div.footer p.note_not_relevant {
    color: #f66;
}

div.footer p time {
    color: #333;
}

